@@ -99,7 +99,7 @@ repository = %(repository_path)s
         parameter_list = [config['git_binary'], 'clone',
                           config['vcs_repository']]
         if branch is not None:
-          parameter_list.extend(['-d',branch])
+          parameter_list.extend(['-b',branch])
         parameter_list.append(repository_path)
         subprocess.check_call(parameter_list)
         # XXX this looks like to not wait the end of the command
